nsi.granulate.GranulateOffice'

Package nsi :: Package granulate :: Module GranulateOffice' |
[hide private]
[frames] | no frames]

# Module GranulateOffice'

source code

Author: Ronaldo Amaral Santos <ronaldinho.as@gmail.com>

Classes | [hide private]
| ConectionServerError
| GranulateOffice - Provide the grain extraction functionality for ms-office and odf documents...

Variables | [hide private]
| APPLICATION_ERROR = `-32500`
| False = `False`
| FastMarshaller = `None`
| FastParser = `None`
| FastUnmarshaller = `None`
| INTERNAL_ERROR = `-32603`
| INVALID_ENCODING_CHAR = `-32702`
| INVALID_METHOD_PARAMS = `-32602`
| INVALID_XMLRPC = `-32600`
| MAXINT = `2147483647`
| METHOD_NOT_FOUND = `-32601`
| MININT = `-2147483648`
| NOT_WELLFORMED_ERROR = `-32700`
| PARSE_ERROR = `-32700`
| SERVER_ERROR = `-32600`
| SYSTEM_ERROR = `-32400`
| SgmlopParser = `None`
| StringTypes = ``(`<type 'str'>`,` <type 'unicode'>`)``
| TRANSPORT_ERROR = `-32300`
| True = `True`
| UNSUPPORTED_ENCODING = `-32701`
| WRAPPERS = ``(`<class xmlrpclib.DateTime at 0xb7b38e0c>`,` <class x`...``

Variables Details | [hide private]

  ### WRAPPERS Value:
      (<class xmlrpclib.DateTime at 0xb7b38e0c>,
       <class xmlrpclib.Binary at 0xb7b400ec>)